# Changelog

## v1.1.1

Fix call to the removed glue.utils broadcast_to function

## v1.1

First pypi release

## v1.0.1

### Bug Fixes
    - Subsets respect zorder
    - Plot styles survive save/restore

## v1.0

Initial Release